::: wisecon.macro.asset_invest
::: wisecon.macro.boom_index
::: wisecon.macro.cpi
::: wisecon.macro.currency_supply
::: wisecon.macro.customs
::: wisecon.macro.deposit_rate
::: wisecon.macro.deposit_reserve
::: wisecon.macro.faith_index
::: wisecon.macro.fdi
::: wisecon.macro.forex_deposit
::: wisecon.macro.forex_loan
::: wisecon.macro.gdp
::: wisecon.macro.gold_currency
::: wisecon.macro.goodes_index
::: wisecon.macro.gov_income
::: wisecon.macro.hose_index
::: wisecon.macro.imp_intrestraten
::: wisecon.macro.indus_grow
::: wisecon.macro.lpr
::: wisecon.macro.new_loan
::: wisecon.macro.oil_price
::: wisecon.macro.pmi
::: wisecon.macro.ppi
::: wisecon.macro.stock_open
::: wisecon.macro.stock_statistics
::: wisecon.macro.tax
::: wisecon.macro.total_retail
::: wisecon.macro.transfer_fund

----
